pub struct ContextToken { /* private fields */ }Expand description
A context token tracking data exposure for an object.
Context tokens are append-only: exposure labels can be added but never removed. The token is a base64-encoded Biscuit with an authority block identifying the session and subsequent blocks recording exposure labels.
Implementations
Sourceimpl ContextToken
impl ContextToken
Sourcepub fn exposure_labels(&self) -> &[ExposureLabel]
pub fn exposure_labels(&self) -> &[ExposureLabel]
Get the current exposure labels.
Sourcepub fn has_exposure(&self, label: &ExposureLabel) -> bool
pub fn has_exposure(&self, label: &ExposureLabel) -> bool
Check if this context has a specific exposure label.
Sourcepub fn is_exposed(&self) -> bool
pub fn is_exposed(&self) -> bool
Check if this context has any exposure labels.