pub struct CListPolicy { /* private fields */ }Expand description
CList (Capability List) policy backend.
Each object has a capability space listing the targets it can access and the operations it can perform. Data classifications map targets to exposure labels. Exposure rules define which targets are blocked when specific exposure labels are present.
Implementations
Sourceimpl CListPolicy
impl CListPolicy
Sourcepub fn from_config(config: PolicyConfig) -> CListPolicy
pub fn from_config(config: PolicyConfig) -> CListPolicy
Create a CList policy from a parsed configuration.
Sourcepub fn from_toml(content: &str) -> Result<CListPolicy, PolicyConfigError>
pub fn from_toml(content: &str) -> Result<CListPolicy, PolicyConfigError>
Create a CList policy from a TOML string.
Sourcepub fn from_file(path: &Path) -> Result<CListPolicy, PolicyConfigError>
pub fn from_file(path: &Path) -> Result<CListPolicy, PolicyConfigError>
Create a CList policy from a TOML file.
Sourcepub fn empty() -> CListPolicy
pub fn empty() -> CListPolicy
Create an empty policy (useful for testing).